**Devlog guidelines:**
- All new code needs to be tested and documented. Add daily tasks accordingly.
- The written dissertation (or at least the notes to write it) needs to move along with all the other goals.
# Daily sprint goals

- ~~find info about continuous integration~~
- ~~set up a goal tracking system~~
- ~~make a use case diagram~~

# Tasks for the day

- [x] set up a kanban board
- [x] set up daily notes
- [x] find info about pylint
- [x] find info about github actions
- [x] figure out how to use plantUML
- [x] make a first attempt at a use case diagram
- [x] make the actual use case diagram

# Notes

- plantUML seems to handle redundancies in the notation really well, and frees me from having to position components manually on the graphs. It's much easier to go from textual description to UML this way because of the text-based description language.
- the use case diagram is probably wrong, but I'll address that later

# Shutdown and Retrospective

- [ ] test and validate all new code (NONE ADDED)
- [x] commit to the remote repo
- [x] make a schedule for tomorrow

**Did anything go wrong? What could have been done better, and how?**
- Improper time blocking led to low efficiency; 

